@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.087-6-g63930ac
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.088-2-g23c2efc
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sw=4 tw=78 et :
 
-our $VERSION = '0.088';
+our $VERSION = '0.089';
 
 use Moose;
 with
@@ -179,7 +179,7 @@ sub configure
         'MojibakeTests',
         [ 'Test::ReportPrereqs' => { ':version' => '0.019', verify_prereqs => 1 } ],
         'Test::Portability',
-        'Test::CleanNamespaces',
+        [ 'Test::CleanNamespaces' => { ':version' => '0.006' } ],
 
 
         # Munge Files
@@ -366,7 +366,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.088
+version 0.089
 
 =head1 SYNOPSIS
 
